@@ -1,5 +1,5 @@
 from .http_status_server import HttpHealthServer
-from .task_args import get_kafka_binder_brokers, get_input_channel, get_output_channel, get_args
+from .task_args import get_kafka_binder_brokers, get_input_channel, get_output_channel, get_args, get_cmd_arg
 
 from .task_status.task_status import TaskStatus
 
