@@ -35,17 +35,17 @@ def get_task_name():
     return get_cmd_arg('spring.cloud.task.name')
 
 
-def get_cmd_arg(name):
-    d = defaultdict(list)
-    for cmd_args in sys.argv[1:]:
-        cmd_arg = cmd_args.split('=')
-        if len(cmd_arg) == 2:
-            d[cmd_arg[0].lstrip('-')].append(cmd_arg[1])
+# def get_cmd_arg(name):
+#     d = defaultdict(list)
+#     for cmd_args in sys.argv[1:]:
+#         cmd_arg = cmd_args.split('=')
+#         if len(cmd_arg) == 2:
+#             d[cmd_arg[0].lstrip('-')].append(cmd_arg[1])
 
-    if name in d:
-        return d[name][0]
-    else:
-        print('Unknown command line arg requested: {}'.format(name))
+#     if name in d:
+#         return d[name][0]
+#     else:
+#         print('Unknown command line arg requested: {}'.format(name))
 
 
 def get_env_var(name):
