@@ -25,9 +25,9 @@ class SCDF(TaskStatus):
         self.engine.execute(start_task_statement, start_time=now, last_updated=now, task_id=self.task_id)
 
     def completed(self):
-        self.task_id = get_task_id()
-        self.engine = create_engine(get_db_url())
-        self.connection = self.engine.connect()
+        # self.task_id = get_task_id()
+        # self.engine = create_engine(get_db_url())
+        # self.connection = self.engine.connect()
 
         """Set the TASK_EXECUTION's END_TIME, EXIST_CODE=0 and EXIST_MESSAGE/ERROR_MESSAGE must be null """
         now = datetime.datetime.now()
